Release Notes
=============

.. changelog::
    :changelog-url: https://amal-khailtash.github.io/pyipxact-de/release_notes.html
    :pypi: https://pypi.org/project/pyipxact-de/
    :github: https://github.com/amal-khailtash/pyipxact-de/releases/
